import { RequestState, QueryConfig, APIConnector, ResponseState, AutocompleteQueryConfig, AutocompleteResponseState } from '@elastic/search-ui';
import { estypes } from '@elastic/elasticsearch';

type SearchRequest = estypes.SearchRequest;
type PostProcessRequestBodyFn = (requestBody: SearchRequest, requestState: RequestState, queryConfig: QueryConfig) => SearchRequest;
interface CloudHost {
    id: string;
}
type ConnectionOptions = {
    host?: string;
    cloud?: CloudHost;
    index: string;
    apiKey?: string;
    connectionOptions?: {
        headers?: Record<string, string>;
    };
};

declare class ElasticsearchAPIConnector implements APIConnector {
    private config;
    private postProcessRequestBodyFn?;
    constructor(config: ConnectionOptions, postProcessRequestBodyFn?: PostProcessRequestBodyFn);
    onResultClick(): void;
    onAutocompleteResultClick(): void;
    onSearch(state: RequestState, queryConfig: QueryConfig): Promise<ResponseState>;
    onAutocomplete(state: RequestState, queryConfig: AutocompleteQueryConfig): Promise<AutocompleteResponseState>;
}

interface APIProxyConnectorOptions {
    basePath?: string;
    fetchOptions?: RequestInit;
}
declare class APIProxyConnector implements APIConnector {
    private readonly basePath;
    private readonly fetchOptions;
    constructor({ basePath, fetchOptions }?: APIProxyConnectorOptions);
    private request;
    onSearch(state: RequestState, queryConfig: QueryConfig): Promise<ResponseState>;
    onAutocomplete(state: RequestState, queryConfig: AutocompleteQueryConfig): Promise<AutocompleteResponseState>;
    onResultClick(): void;
    onAutocompleteResultClick(): void;
}

export { APIProxyConnector as ApiProxyConnector, type CloudHost, type ConnectionOptions, type PostProcessRequestBodyFn, type SearchRequest, ElasticsearchAPIConnector as default };
